@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2014 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -22,8 +22,6 @@
 import os
 import sys
 
-from glances.core.glances_logging import glances_logger
-
 # Global information
 appname = 'glances'
 version = __import__('glances').__version__
@@ -46,9 +44,13 @@ sys_prefix = os.path.realpath(os.path.dirname(appname_path))
 
 # Set the plugins path
 plugins_path = os.path.realpath(os.path.join(work_path, '..', 'plugins'))
-sys_path = sys.path[:]
-sys.path.insert(0, plugins_path)
 
+# Set the export module path
+exports_path = os.path.realpath(os.path.join(work_path, '..', 'exports'))
+
+sys_path = sys.path[:]
+sys.path.insert(1, plugins_path)
+sys.path.insert(1, exports_path)
 
 def get_locale_path(paths):
     for path in paths:
@@ -61,17 +63,3 @@ i18n_path = os.path.realpath(os.path.join(work_path, '..', '..', 'i18n'))
 user_i18n_path = os.path.join(os.path.expanduser('~/.local'), 'share', 'locale')
 sys_i18n_path = os.path.join(sys_prefix, 'share', 'locale')
 locale_dir = get_locale_path([i18n_path, user_i18n_path, sys_i18n_path])
-
-# Create and init the logging instance
-logger = glances_logger()
-
-# Instances shared between all Glances scripts
-# ============================================
-
-# Glances_processes for processcount and processlist plugins
-from glances.core.glances_processes import GlancesProcesses
-glances_processes = GlancesProcesses()
-
-# The global instance for the logs
-from glances.core.glances_logs import GlancesLogs
-glances_logs = GlancesLogs()
