@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2014 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -27,7 +27,8 @@ import tempfile
 
 # Import Glances libs
 from glances.core.glances_config import Config
-from glances.core.glances_globals import appname, is_windows, logger, psutil_version, version
+from glances.core.glances_globals import appname, is_windows, psutil_version, version
+from glances.core.glances_logging import logger
 
 
 class GlancesMain(object):
@@ -50,6 +51,36 @@ class GlancesMain(object):
     username = "glances"
     password = ""
 
+    # Exemple of use
+    example_of_use = "\
+Examples of use:\n\
+\n\
+Monitor local machine (standalone mode):\n\
+  $ glances\n\
+\n\
+Monitor local machine with the Web interface (Web UI):\n\
+  $ glances -w\n\
+  Glances web server started on http://0.0.0.0:61208/\n\
+\n\
+Monitor local machine and export stats to a CSV file (standalone mode):\n\
+  $ glances --export-csv\n\
+\n\
+Monitor local machine and export stats to a InfluxDB server with 5s refresh time (standalone mode):\n\
+  $ glances -t 5 --export-influxdb\n\
+\n\
+Start a Glances server (server mode):\n\
+  $ glances -s\n\
+\n\
+Connect Glances to a Glances server (client mode):\n\
+  $ glances -c <ip_server>\n\
+\n\
+Connect Glances to a Glances server and export stats to a StatsD server (client mode):\n\
+  $ glances -c <ip_server> --export-statsd\n\
+\n\
+Start the client browser (browser mode):\n\
+  $ glances --browser\n\
+    "
+
     def __init__(self):
         """Manage the command line arguments."""
         self.args = self.parse_args()
@@ -58,7 +89,10 @@ class GlancesMain(object):
         """Init all the command line arguments."""
         _version = "Glances v" + version + " with psutil v" + psutil_version
         parser = argparse.ArgumentParser(
-            prog=appname, conflict_handler='resolve')
+            prog=appname,
+            conflict_handler='resolve',
+            formatter_class=argparse.RawDescriptionHelpFormatter,
+            epilog=self.example_of_use)
         parser.add_argument(
             '-V', '--version', action='version', version=_version)
         parser.add_argument('-d', '--debug', action='store_true', default=False,
@@ -74,8 +108,12 @@ class GlancesMain(object):
                             dest='disable_fs', help=_('disable filesystem module'))
         parser.add_argument('--disable-sensors', action='store_true', default=False,
                             dest='disable_sensors', help=_('disable sensors module'))
+        parser.add_argument('--disable-raid', action='store_true', default=False,
+                            dest='disable_raid', help=_('disable RAID module'))
+        parser.add_argument('--disable-docker', action='store_true', default=False,
+                            dest='disable_docker', help=_('disable Docker module'))
         parser.add_argument('--disable-left-sidebar', action='store_true', default=False,
-                            dest='disable_left_sidebar', help=_('disable network, disk io, FS and sensors modules'))
+                            dest='disable_left_sidebar', help=_('disable network, disk io, FS and sensors modules (need Py3Sensors lib)'))
         parser.add_argument('--disable-process', action='store_true', default=False,
                             dest='disable_process', help=_('disable process module'))
         parser.add_argument('--disable-log', action='store_true', default=False,
@@ -85,12 +123,16 @@ class GlancesMain(object):
         parser.add_argument('--enable-process-extended', action='store_true', default=False,
                             dest='enable_process_extended', help=_('enable extended stats on top process'))
         parser.add_argument('--enable-history', action='store_true', default=False,
-                            dest='enable_history', help=_('enable the history mode'))
+                            dest='enable_history', help=_('enable the history mode (need MatPlotLib lib)'))
         parser.add_argument('--path-history', default=tempfile.gettempdir(),
                             dest='path_history', help=_('Set the export path for graph history'))
-        # CSV output feature
-        parser.add_argument('--output-csv', default=None,
-                            dest='output_csv', help=_('export stats to a CSV file'))
+        # Export modules feature
+        parser.add_argument('--export-csv', default=None,
+                            dest='export_csv', help=_('export stats to a CSV file'))
+        parser.add_argument('--export-influxdb', action='store_true', default=False,
+                            dest='export_influxdb', help=_('export stats to an InfluxDB server (need InfluDB lib)'))
+        parser.add_argument('--export-statsd', action='store_true', default=False,
+                            dest='export_statsd', help=_('export stats to a Statsd server (need StatsD lib)'))
         # Client/Server option
         parser.add_argument('-c', '--client', dest='client',
                             help=_('connect to a Glances server by IPv4/IPv6 address or hostname'))
@@ -123,7 +165,7 @@ class GlancesMain(object):
         parser.add_argument('-t', '--time', default=self.refresh_time, type=float,
                             dest='time', help=_('set refresh time in seconds [default: {0} sec]').format(self.refresh_time))
         parser.add_argument('-w', '--webserver', action='store_true', default=False,
-                            dest='webserver', help=_('run Glances in web server mode'))
+                            dest='webserver', help=_('run Glances in web server mode (need Bootle lib)'))
         # Display options
         parser.add_argument('-f', '--process-filter', default=None, type=str,
                             dest='process_filter', help=_('set the process filter pattern (regular expression)'))
@@ -171,6 +213,7 @@ class GlancesMain(object):
         # In web server mode, defaul refresh time: 5 sec
         if args.webserver:
             args.time = 5
+            args.process_short_name = True
 
         # Server or client login/password
         args.username = self.username
