@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2014 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -17,14 +17,205 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-# Import Glances lib
-from glances.core.glances_globals import is_linux, is_bsd, is_mac, is_windows, logger
-from glances.core.glances_timer import Timer, getTimeSinceLastUpdate
-
 # Import Python lib
-import psutil
+import collections
+import operator
+import os
 import re
 
+# Import psutil
+import psutil
+
+# Import Glances lib
+from glances.core.glances_globals import is_bsd, is_linux, is_mac, is_windows
+from glances.core.glances_logging import logger
+from glances.core.glances_timer import getTimeSinceLastUpdate, Timer
+
+
+def is_kernel_thread(proc):
+    """ Return True if proc is a kernel thread, False instead. """
+    try:
+        return os.getpgid(proc.pid) == 0
+    except OSError:  # Python >= 3.3 raises ProcessLookupError, which inherits OSError
+        # return False is process is dead
+        return False
+
+
+class ProcessTreeNode(object):
+
+    """
+    Represent a process tree.
+
+    We avoid recursive algorithm to manipulate the tree because function calls are expensive with CPython.
+    """
+
+    def __init__(self, process=None, stats=None, sort_key=None, root=False):
+        self.process = process
+        self.stats = stats
+        self.children = []
+        self.children_sorted = False
+        self.sort_key = sort_key
+        self.reverse_sorting = (self.sort_key != "name")
+        self.is_root = root
+
+    def __str__(self):
+        """ Return the tree as a string for debugging. """
+        lines = []
+        nodes_to_print = collections.deque([collections.deque([("#", self)])])
+        while nodes_to_print:
+            indent_str, current_node = nodes_to_print[-1].pop()
+            if not nodes_to_print[-1]:
+                nodes_to_print.pop()
+            if current_node.is_root:
+                lines.append(indent_str)
+            else:
+                lines.append("%s[%s]" % (indent_str, current_node.process.name()))
+            indent_str = " " * (len(lines[-1]) - 1)
+            children_nodes_to_print = collections.deque()
+            for child in current_node.children:
+                if child is current_node.children[-1]:
+                    tree_char = "└─"
+                else:
+                    tree_char = "├─"
+                children_nodes_to_print.appendleft((indent_str + tree_char, child))
+            if children_nodes_to_print:
+                nodes_to_print.append(children_nodes_to_print)
+        return "\n".join(lines)
+
+    def set_sorting(self, key, reverse):
+        """ Set sorting key or func for user with __iter__ (affects the whole tree from this node). """
+        if (self.sort_key != key) or (self.reverse_sorting != reverse):
+            nodes_to_flag_unsorted = collections.deque([self])
+            while nodes_to_flag_unsorted:
+                current_node = nodes_to_flag_unsorted.pop()
+                current_node.children_sorted = False
+                current_node.sort_key = key
+                current_node.reverse_sorting = reverse
+                nodes_to_flag_unsorted.extend(current_node.children)
+
+    def get_weight(self):
+        """ Return "weight" of a process and all its children for sorting. """
+        if self.sort_key == "name":
+            return self.stats[self.sort_key]
+
+        # sum ressource usage for self and children
+        total = 0
+        nodes_to_sum = collections.deque([self])
+        while nodes_to_sum:
+            current_node = nodes_to_sum.pop()
+            if isinstance(self.sort_key, collections.Callable):
+                total += self.sort_key(current_node.stats)
+            elif self.sort_key == "io_counters":
+                stats = current_node.stats[self.sort_key]
+                total += stats[0] - stats[2] + stats[1] - stats[3]
+            elif self.sort_key == "cpu_times":
+                total += sum(current_node.stats[self.sort_key])
+            else:
+                total += current_node.stats[self.sort_key]
+            nodes_to_sum.extend(current_node.children)
+
+        return total
+
+    def __len__(self):
+        """Return the number of nodes in the tree."""
+        total = 0
+        nodes_to_sum = collections.deque([self])
+        while nodes_to_sum:
+            current_node = nodes_to_sum.pop()
+            if not current_node.is_root:
+                total += 1
+            nodes_to_sum.extend(current_node.children)
+        return total
+
+    def __iter__(self):
+        """ Iterator returning ProcessTreeNode in sorted order, recursively. """
+        if not self.is_root:
+            yield self
+        if not self.children_sorted:
+            # optimization to avoid sorting twice (once when limiting the maximum processes to grab stats for,
+            # and once before displaying)
+            self.children.sort(key=self.__class__.get_weight, reverse=self.reverse_sorting)
+            self.children_sorted = True
+        for child in self.children:
+            for n in iter(child):
+                yield n
+
+    def iter_children(self, exclude_incomplete_stats=True):
+        """
+        Iterator returning ProcessTreeNode in sorted order (only children of this node, non recursive).
+
+        If exclude_incomplete_stats is True, exclude processes not having full statistics.
+        It can happen after a resort (change of sort key) because process stats are not grabbed immediately,
+        but only at next full update.
+        """
+        if not self.children_sorted:
+            # optimization to avoid sorting twice (once when limiting the maximum processes to grab stats for,
+            # and once before displaying)
+            self.children.sort(key=self.__class__.get_weight, reverse=self.reverse_sorting)
+            self.children_sorted = True
+        for child in self.children:
+            if (not exclude_incomplete_stats) or ("time_since_update" in child.stats):
+                yield child
+
+    def find_process(self, process):
+        """ Search in tree for the ProcessTreeNode owning process, return it or None if not found. """
+        nodes_to_search = collections.deque([self])
+        while nodes_to_search:
+            current_node = nodes_to_search.pop()
+            if (not current_node.is_root) and (current_node.process.pid == process.pid):
+                return current_node
+            nodes_to_search.extend(current_node.children)
+
+    @staticmethod
+    def build_tree(process_dict, sort_key, hide_kernel_threads):
+        """ Build a process tree using using parent/child relationships, and return the tree root node. """
+        tree_root = ProcessTreeNode(root=True)
+        nodes_to_add_last = collections.deque()
+
+        # first pass: add nodes whose parent are in the tree
+        for process, stats in process_dict.items():
+            new_node = ProcessTreeNode(process, stats, sort_key)
+            try:
+                parent_process = process.parent()
+            except psutil.NoSuchProcess:
+                # parent is dead, consider no parent
+                parent_process = None
+            if parent_process is None:
+                # no parent, add this node at the top level
+                tree_root.children.append(new_node)
+            else:
+                parent_node = tree_root.find_process(parent_process)
+                if parent_node is not None:
+                    # parent is already in the tree, add a new child
+                    parent_node.children.append(new_node)
+                else:
+                    # parent is not in tree, add this node later
+                    nodes_to_add_last.append(new_node)
+
+        # next pass(es): add nodes to their parents if it could not be done in previous pass
+        while nodes_to_add_last:
+            node_to_add = nodes_to_add_last.popleft()  # pop from left and append to right to avoid infinite loop
+            try:
+                parent_process = node_to_add.process.parent()
+            except psutil.NoSuchProcess:
+                # parent is dead, consider no parent, add this node at the top level
+                tree_root.children.append(node_to_add)
+            else:
+                if parent_process is None:
+                    # parent is None now, but was not at previous pass (can occur on Windows only)
+                    # consider no parent, add this node at the top level
+                    tree_root.children.append(node_to_add)
+                else:
+                    parent_node = tree_root.find_process(parent_process)
+                    if parent_node is not None:
+                        # parent is already in the tree, add a new child
+                        parent_node.children.append(node_to_add)
+                    else:
+                        # parent is not in tree, add this node later
+                        nodes_to_add_last.append(node_to_add)
+
+        return tree_root
+
 
 class GlancesProcesses(object):
 
@@ -46,12 +237,17 @@ class GlancesProcesses(object):
         # value = [ read_bytes_old, write_bytes_old ]
         self.io_old = {}
 
+        # Wether or not to enable process tree
+        self._enable_tree = False
+        self.process_tree = None
+
         # Init stats
         self.resetsort()
         self.processlist = []
-        self.processcount = {'total': 0, 'running': 0, 'sleeping': 0, 'thread': 0}
+        self.processcount = {
+            'total': 0, 'running': 0, 'sleeping': 0, 'thread': 0}
 
-        # Tag to enable/disable the processes stats (to reduce the Glances CPU comsumption)
+        # Tag to enable/disable the processes stats (to reduce the Glances CPU consumption)
         # Default is to enable the processes stats
         self.disable_tag = False
 
@@ -66,6 +262,9 @@ class GlancesProcesses(object):
         self.process_filter = None
         self.process_filter_re = None
 
+        # Whether or not to hide kernel threads
+        self.no_kernel_threads = False
+
     def enable(self):
         """Enable process stats."""
         self.disable_tag = False
@@ -95,14 +294,14 @@ class GlancesProcesses(object):
 
     def set_process_filter(self, value):
         """Set the process filter"""
-        logger.info(_("Set process filter to %s") % value)
+        logger.info("Set process filter to {0}".format(value))
         self.process_filter = value
         if value is not None:
             try:
                 self.process_filter_re = re.compile(value)
-                logger.debug(_("Process filter regular expression compilation OK: %s") % self.get_process_filter())
-            except:
-                logger.error(_("Can not compile process filter regular expression: %s") % value)
+                logger.debug("Process filter regex compilation OK: {0}".format(self.get_process_filter()))
+            except Exception:
+                logger.error("Cannot compile process filter regex: {0}".format(value))
                 self.process_filter_re = None
         else:
             self.process_filter_re = None
@@ -125,9 +324,21 @@ class GlancesProcesses(object):
             # logger.debug(self.get_process_filter() + " <> " + value + " => " + str(self.get_process_filter_re().match(value) is None))
             return self.get_process_filter_re().match(value) is None
 
+    def disable_kernel_threads(self):
+        """ Ignore kernel threads in process list. """
+        self.no_kernel_threads = True
+
+    def enable_tree(self):
+        """ Enable process tree. """
+        self._enable_tree = True
+
+    def is_tree_enabled(self):
+        """ Return True if process tree is enabled, False instead. """
+        return self._enable_tree
+
     def __get_process_stats(self, proc,
                             mandatory_stats=True,
-                            standard_stats=True, 
+                            standard_stats=True,
                             extended_stats=False):
         """
         Get process stats of the proc processes (proc is returned psutil.process_iter())
@@ -143,10 +354,19 @@ class GlancesProcesses(object):
         procstat = proc.as_dict(attrs=['pid'])
 
         if mandatory_stats:
-            procstat['mandatory_stats'] = True 
+            procstat['mandatory_stats'] = True
 
             # Process CPU, MEM percent and name
-            procstat.update(proc.as_dict(attrs=['cpu_percent', 'memory_percent', 'name'], ad_value=''))
+            try:
+                procstat.update(
+                    proc.as_dict(attrs=['cpu_percent', 'memory_percent', 'name', 'cpu_times'], ad_value=''))
+            except psutil.NoSuchProcess:
+                # Correct issue #414
+                return None
+            if procstat['cpu_percent'] == '' or procstat['memory_percent'] == '':
+                # Do not display process if we cannot get the basic
+                # cpu_percent or memory_percent stats
+                return None
 
             # Process command line (cached with internal cache)
             try:
@@ -154,7 +374,8 @@ class GlancesProcesses(object):
             except KeyError:
                 # Patch for issue #391
                 try:
-                    self.cmdline_cache[procstat['pid']] = ' '.join(proc.cmdline())
+                    self.cmdline_cache[
+                        procstat['pid']] = ' '.join(proc.cmdline())
                 except (AttributeError, UnicodeDecodeError, psutil.AccessDenied, psutil.NoSuchProcess):
                     self.cmdline_cache[procstat['pid']] = ""
             procstat['cmdline'] = self.cmdline_cache[procstat['pid']]
@@ -173,14 +394,16 @@ class GlancesProcesses(object):
                 except (psutil.AccessDenied, psutil.NoSuchProcess):
                     # Access denied to process IO (no root account)
                     # NoSuchProcess (process die between first and second grab)
-                    # Put 0 in all values (for sort) and io_tag = 0 (for display)
+                    # Put 0 in all values (for sort) and io_tag = 0 (for
+                    # display)
                     procstat['io_counters'] = [0, 0] + [0, 0]
                     io_tag = 0
                 else:
                     # For IO rate computation
                     # Append saved IO r/w bytes
                     try:
-                        procstat['io_counters'] = io_new + self.io_old[procstat['pid']]
+                        procstat['io_counters'] = io_new + \
+                            self.io_old[procstat['pid']]
                     except KeyError:
                         procstat['io_counters'] = io_new + [0, 0]
                     # then save the IO r/w bytes
@@ -191,7 +414,7 @@ class GlancesProcesses(object):
                 procstat['io_counters'] += [io_tag]
 
         if standard_stats:
-            procstat['standard_stats'] = True 
+            procstat['standard_stats'] = True
 
             # Process username (cached with internal cache)
             try:
@@ -200,7 +423,7 @@ class GlancesProcesses(object):
                 try:
                     self.username_cache[procstat['pid']] = proc.username()
                 except psutil.NoSuchProcess:
-                        self.username_cache[procstat['pid']] = "?"
+                    self.username_cache[procstat['pid']] = "?"
                 except (KeyError, psutil.AccessDenied):
                     try:
                         self.username_cache[procstat['pid']] = proc.uids().real
@@ -210,14 +433,15 @@ class GlancesProcesses(object):
 
             # Process status, nice, memory_info and cpu_times
             try:
-                procstat.update(proc.as_dict(attrs=['status', 'nice', 'memory_info', 'cpu_times']))
+                procstat.update(
+                    proc.as_dict(attrs=['status', 'nice', 'memory_info', 'cpu_times']))
             except psutil.NoSuchProcess:
                 pass
             else:
                 procstat['status'] = str(procstat['status'])[:1].upper()
 
         if extended_stats and not self.disable_extended_tag:
-            procstat['extended_stats'] = True 
+            procstat['extended_stats'] = True
 
             # CPU affinity (Windows and Linux only)
             try:
@@ -268,12 +492,13 @@ class GlancesProcesses(object):
             # http://www.cyberciti.biz/faq/linux-which-process-is-using-swap/
             if is_linux:
                 try:
-                    procstat['memory_swap'] = sum([v.swap for v in proc.memory_maps()])
+                    procstat['memory_swap'] = sum(
+                        [v.swap for v in proc.memory_maps()])
                 except psutil.NoSuchProcess:
                     pass
                 except psutil.AccessDenied:
                     procstat['memory_swap'] = None
-                except:
+                except Exception:
                     # Add a dirty except to handle the PsUtil issue #413
                     procstat['memory_swap'] = None
 
@@ -281,7 +506,7 @@ class GlancesProcesses(object):
             try:
                 procstat['tcp'] = len(proc.connections(kind="tcp"))
                 procstat['udp'] = len(proc.connections(kind="udp"))
-            except:
+            except Exception:
                 procstat['tcp'] = None
                 procstat['udp'] = None
 
@@ -295,7 +520,7 @@ class GlancesProcesses(object):
             else:
                 procstat['ionice'] = None
 
-            #logger.debug(procstat)
+            # logger.debug(procstat)
 
         return procstat
 
@@ -305,7 +530,8 @@ class GlancesProcesses(object):
         """
         # Reset the stats
         self.processlist = []
-        self.processcount = {'total': 0, 'running': 0, 'sleeping': 0, 'thread': 0}
+        self.processcount = {
+            'total': 0, 'running': 0, 'sleeping': 0, 'thread': 0}
 
         # Do not process if disable tag is set
         if self.disable_tag:
@@ -317,10 +543,15 @@ class GlancesProcesses(object):
         # Build an internal dict with only mandatories stats (sort keys)
         processdict = {}
         for proc in psutil.process_iter():
+            # Ignore kernel threads if needed
+            if (self.no_kernel_threads and (not is_windows)
+                    and is_kernel_thread(proc)):
+                continue
+
             # If self.get_max_processes() is None: Only retreive mandatory stats
             # Else: retreive mandatory and standard stats
-            s = self.__get_process_stats(proc, 
-                                         mandatory_stats=True, 
+            s = self.__get_process_stats(proc,
+                                         mandatory_stats=True,
                                          standard_stats=self.get_max_processes() is None)
             # Continue to the next process if it has to be filtered
             if s is None or (self.is_filtered(s['cmdline']) and self.is_filtered(s['name'])):
@@ -331,60 +562,90 @@ class GlancesProcesses(object):
             # ignore the 'kernel_task' process on OS X
             # waiting for upstream patch from psutil
             if (is_bsd and processdict[proc]['name'] == 'idle' or
-                is_windows and processdict[proc]['name'] == 'System Idle Process' or
-                is_mac and processdict[proc]['name'] == 'kernel_task'):
+                    is_windows and processdict[proc]['name'] == 'System Idle Process' or
+                    is_mac and processdict[proc]['name'] == 'kernel_task'):
                 continue
             # Update processcount (global statistics)
             try:
                 self.processcount[str(proc.status())] += 1
             except KeyError:
                 # Key did not exist, create it
-                self.processcount[str(proc.status())] = 1
+                try:
+                    self.processcount[str(proc.status())] = 1
+                except psutil.NoSuchProcess:
+                    pass
+            except psutil.NoSuchProcess:
+                pass
             else:
                 self.processcount['total'] += 1
             # Update thread number (global statistics)
             try:
                 self.processcount['thread'] += proc.num_threads()
-            except:
+            except Exception:
                 pass
 
-        # Process optimization
-        # Only retreive stats for visible processes (get_max_processes)
-        if self.get_max_processes() is not None:
-            # Sort the internal dict and cut the top N (Return a list of tuple)
-            # tuple=key (proc), dict (returned by __get_process_stats)
-            try:
-                processiter = sorted(processdict.items(), key=lambda x: x[1][self.getsortkey()], reverse=True)
-            except TypeError:
-                # Fallback to all process (issue #423)
+        if self._enable_tree:
+            self.process_tree = ProcessTreeNode.build_tree(processdict,
+                                                           self.getsortkey(),
+                                                           self.no_kernel_threads)
+
+            for i, node in enumerate(self.process_tree):
+                # Only retreive stats for visible processes (get_max_processes)
+                if (self.get_max_processes() is not None) and (i >= self.get_max_processes()):
+                    break
+
+                # add standard stats
+                new_stats = self.__get_process_stats(node.process,
+                                                     mandatory_stats=False,
+                                                     standard_stats=True,
+                                                     extended_stats=False)
+                if new_stats is not None:
+                    node.stats.update(new_stats)
+
+                # Add a specific time_since_update stats for bitrate
+                node.stats['time_since_update'] = time_since_update
+
+        else:
+            # Process optimization
+            # Only retreive stats for visible processes (get_max_processes)
+            if self.get_max_processes() is not None:
+                # Sort the internal dict and cut the top N (Return a list of tuple)
+                # tuple=key (proc), dict (returned by __get_process_stats)
+                try:
+                    processiter = sorted(
+                        processdict.items(), key=lambda x: x[1][self.getsortkey()], reverse=True)
+                except (KeyError, TypeError) as e:
+                    logger.error("Cannot sort process list by %s (%s)" % (self.getsortkey(), e))
+                    logger.error("%s" % str(processdict.items()[0]))
+                    # Fallback to all process (issue #423)
+                    processloop = processdict.items()
+                    first = False
+                else:
+                    processloop = processiter[0:self.get_max_processes()]
+                    first = True
+            else:
+                # Get all processes stats
                 processloop = processdict.items()
                 first = False
-            else:
-                processloop = processiter[0:self.get_max_processes()]
-                first = True
-        else:
-            # Get all processes stats
-            processloop = processdict.items()
-            first = False        
-        for i in processloop:
-            # Already existing mandatory stats
-            procstat = i[1]
-            if self.get_max_processes() is not None:
-                # Update with standard stats
-                # and extended stats but only for TOP (first) process
-                s = self.__get_process_stats(i[0], 
-                                             mandatory_stats=False, 
-                                             standard_stats=True,
-                                             extended_stats=first)
-                if s is None:
-                    continue
-                procstat.update(s)
-            # Add a specific time_since_update stats for bitrate
-            procstat['time_since_update'] = time_since_update
-            # Update process list
-            self.processlist.append(procstat)
-            # Next...
-            first = False
+            for i in processloop:
+                # Already existing mandatory stats
+                procstat = i[1]
+                if self.get_max_processes() is not None:
+                    # Update with standard stats
+                    # and extended stats but only for TOP (first) process
+                    s = self.__get_process_stats(i[0],
+                                                 mandatory_stats=False,
+                                                 standard_stats=True,
+                                                 extended_stats=first)
+                    if s is None:
+                        continue
+                    procstat.update(s)
+                # Add a specific time_since_update stats for bitrate
+                procstat['time_since_update'] = time_since_update
+                # Update process list
+                self.processlist.append(procstat)
+                # Next...
+                first = False
 
         # Clean internals caches if timeout is reached
         if self.cache_timer.finished():
@@ -401,6 +662,10 @@ class GlancesProcesses(object):
         """Get the processlist."""
         return self.processlist
 
+    def gettree(self):
+        """Get the process tree."""
+        return self.process_tree
+
     def getsortkey(self):
         """Get the current sort key"""
         if self.getmanualsortkey() is not None:
@@ -419,6 +684,8 @@ class GlancesProcesses(object):
     def setmanualsortkey(self, sortedby):
         """Set the current sort key for manual sort."""
         self.processmanualsort = sortedby
+        if self._enable_tree and (self.process_tree is not None):
+            self.process_tree.set_sorting(sortedby, sortedby != "name")
         return self.processmanualsort
 
     def setautosortkey(self, sortedby):
@@ -446,21 +713,18 @@ class GlancesProcesses(object):
             # Sum of io_r + io_w
             try:
                 # Sort process by IO rate (sum IO read + IO write)
-                listsorted = sorted(self.processlist,
-                                    key=lambda process: process[sortedby][0] -
-                                    process[sortedby][2] + process[sortedby][1] -
-                                    process[sortedby][3],
-                                    reverse=sortedreverse)
+                self.processlist.sort(key=lambda process: process[sortedby][0] -
+                                      process[sortedby][2] + process[sortedby][1] -
+                                      process[sortedby][3],
+                                      reverse=sortedreverse)
             except Exception:
-                listsorted = sorted(self.processlist,
-                                    key=lambda process: process['cpu_percent'],
-                                    reverse=sortedreverse)
+                self.processlist.sort(key=operator.itemgetter('cpu_percent'),
+                                      reverse=sortedreverse)
         else:
             # Others sorts
-            listsorted = sorted(self.processlist,
-                                key=lambda process: process[sortedby],
-                                reverse=sortedreverse)
-
-        self.processlist = listsorted
+            self.processlist.sort(key=operator.itemgetter(sortedby),
+                                  reverse=sortedreverse)
 
         return self.processlist
+
+glances_processes = GlancesProcesses()
