@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2014 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -32,10 +32,11 @@ except ImportError:  # Python 2
     from SimpleXMLRPCServer import SimpleXMLRPCServer
 
 # Import Glances libs
-from glances.core.glances_globals import logger, version
+from glances.core.glances_autodiscover import GlancesAutoDiscoverClient
+from glances.core.glances_globals import version
+from glances.core.glances_logging import logger
 from glances.core.glances_stats import GlancesStatsServer
 from glances.core.glances_timer import Timer
-from glances.core.glances_autodiscover import GlancesAutoDiscoverClient
 
 
 class GlancesXMLRPCHandler(SimpleXMLRPCRequestHandler):
@@ -159,7 +160,11 @@ class GlancesInstance(object):
 
     def getAllLimits(self):
         # Return all the plugins limits
-        return json.dumps(self.stats.getAllLimits())
+        return json.dumps(self.stats.getAllLimitsAsDict())
+
+    def getAllViews(self):
+        # Return all the plugins views
+        return json.dumps(self.stats.getAllViewsAsDict())
 
     def getAllMonitored(self):
         # Return the processes monitored list
