@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2014 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -23,8 +23,10 @@ import collections
 import os
 import re
 import sys
+import threading
 
-from glances.core.glances_globals import logger, plugins_path, sys_path
+from glances.core.glances_globals import plugins_path, exports_path, sys_path
+from glances.core.glances_logging import logger
 
 # SNMP OID regexp pattern to short system name dict
 oid_to_short_system_name = {'.*Linux.*': 'linux',
@@ -32,7 +34,8 @@ oid_to_short_system_name = {'.*Linux.*': 'linux',
                             '.*BSD.*': 'bsd',
                             '.*Windows.*': 'windows',
                             '.*Cisco.*': 'cisco',
-                            '.*VMware ESXi.*': 'esxi'}
+                            '.*VMware ESXi.*': 'esxi',
+                            '.*NetApp.*': 'netapp'}
 
 
 class GlancesStats(object):
@@ -40,18 +43,22 @@ class GlancesStats(object):
     """This class stores, updates and gives stats."""
 
     def __init__(self, config=None, args=None):
-        # Init the plugin list dict
-        self._plugins = collections.defaultdict(dict)
-
         # Set the argument instance
         self.args = args
 
         # Set the config instance
         self.config = config
 
+        # Init the plugin list dict
+        self._plugins = collections.defaultdict(dict)
         # Load the plugins
         self.load_plugins(args=args)
 
+        # Init the export modules list dict
+        self._exports = collections.defaultdict(dict)
+        # Load the plugins
+        self.load_exports(args=args)
+
         # Load the limits
         self.load_limits(config)
 
@@ -95,15 +102,44 @@ class GlancesStats(object):
                     self._plugins[plugin_name] = plugin.Plugin(args=args, config=self.config)
                 else:
                     self._plugins[plugin_name] = plugin.Plugin(args=args)
-        # Restoring system path
-        sys.path = sys_path
         # Log plugins list
         logger.debug("Available plugins list: {0}".format(self.getAllPlugins()))
 
+    def load_exports(self, args=None):
+        """Load all exports module in the 'exports' folder."""
+        if args is None:
+            return False
+        header = "glances_"
+        # Transform the arguments list into a dict
+        # The aim is to chec if the export module should be loaded
+        args_var = vars(locals()['args'])
+        for item in os.listdir(exports_path):
+            export_name = os.path.basename(item)[len(header):-3].lower()
+            if (item.startswith(header) and
+                    item.endswith(".py") and
+                    item != (header + "export.py") and
+                    item != (header + "history.py") and
+                    args_var['export_' + export_name] is not None and
+                    args_var['export_' + export_name] is not False):
+                # Import the export module
+                export_module = __import__(os.path.basename(item)[:-3])
+                # Add the export to the dictionary
+                # The key is the module name
+                # for example, the file glances_xxx.py
+                # generate self._exports_list["xxx"] = ...
+                self._exports[export_name] = export_module.Export(args=args, config=self.config)
+        # Log plugins list
+        logger.debug("Available exports modules list: {0}".format(self.getAllExports()))
+        return True
+
     def getAllPlugins(self):
         """Return the plugins list."""
         return [p for p in self._plugins]
 
+    def getAllExports(self):
+        """Return the exports modules list."""
+        return [p for p in self._exports]
+
     def load_limits(self, config=None):
         """Load the stats limits."""
         # For each plugins, call the init_limits method
@@ -111,23 +147,24 @@ class GlancesStats(object):
             # logger.debug("Load limits for %s" % p)
             self._plugins[p].load_limits(config)
 
-    def __update__(self, input_stats):
-        """Update all the stats."""
-        if input_stats == {}:
-            # For standalone and server modes
-            # For each plugins, call the update method
-            for p in self._plugins:
-                # logger.debug("Update %s stats" % p)
-                self._plugins[p].update()
-        else:
-            # For Glances client mode
-            # Update plugin stats with items sent by the server
-            for p in input_stats:
-                self._plugins[p].set_stats(input_stats[p])
-
-    def update(self, input_stats={}):
+    def update(self):
         """Wrapper method to update the stats."""
-        self.__update__(input_stats)
+        # For standalone and server modes
+        # For each plugins, call the update method
+        for p in self._plugins:
+            # logger.debug("Update %s stats" % p)
+            self._plugins[p].update()
+
+    def export(self, input_stats={}):
+        """Export all the stats.
+        Each export module is ran in a dedicated thread."""
+        # threads = []
+        for e in self._exports:
+            logger.debug("Export stats using the %s module" % e)
+            thread = threading.Thread(target=self._exports[e].update,
+                                      args=(input_stats,))
+            # threads.append(thread)
+            thread.start()
 
     def getAll(self):
         """Return all the stats (list)"""
@@ -142,6 +179,28 @@ class GlancesStats(object):
             ret[p] = self._plugins[p].get_raw()
         return ret
 
+    def getAllLimits(self):
+        """Return the plugins limits list."""
+        return [self._plugins[p].get_limits() for p in self._plugins]
+
+    def getAllLimitsAsDict(self):
+        """Return all the stats limits (dict)"""
+        ret = {}
+        for p in self._plugins:
+            ret[p] = self._plugins[p].get_limits()
+        return ret
+
+    def getAllViews(self):
+        """Return the plugins views"""
+        return [self._plugins[p].get_views() for p in self._plugins]
+
+    def getAllViewsAsDict(self):
+        """Return all the stats views (dict)"""
+        ret = {}
+        for p in self._plugins:
+            ret[p] = self._plugins[p].get_views()
+        return ret
+
     def get_plugin_list(self):
         """Return the plugin list."""
         self._plugins
@@ -153,6 +212,12 @@ class GlancesStats(object):
         else:
             return None
 
+    def end(self):
+        """End of the Glances stats"""
+        # Close the export module
+        for e in self._exports:
+            self._exports[e].exit()
+
 
 class GlancesStatsServer(GlancesStats):
 
@@ -168,11 +233,19 @@ class GlancesStatsServer(GlancesStats):
 
     def update(self, input_stats={}):
         """Update the stats."""
+        # Force update of all the stats
         GlancesStats.update(self)
 
+        # Build all_stats variable (concatenation of all the stats)
+        self.all_stats = self._set_stats(input_stats)
+
+    def _set_stats(self, input_stats):
+        """Set the stats to the input_stats one"""
         # Build the all_stats with the get_raw() method of the plugins
+        ret = collections.defaultdict(dict)
         for p in self._plugins:
-            self.all_stats[p] = self._plugins[p].get_raw()
+            ret[p] = self._plugins[p].get_raw()
+        return ret
 
     def getAll(self):
         """Return the stats as a list"""
@@ -187,24 +260,27 @@ class GlancesStatsServer(GlancesStats):
             ret[p] = self.all_stats[p]
         return ret
 
-    def getAllPlugins(self):
-        """Return the plugins list."""
-        return [p for p in self._plugins]
-
-    def getAllLimits(self):
-        """Return the plugins limits list."""
-        return [self._plugins[p].get_limits() for p in self._plugins]
-
 
 class GlancesStatsClient(GlancesStats):
 
     """This class stores, updates and gives stats for the client."""
 
-    def __init__(self):
+    def __init__(self, config=None, args=None):
         """Init the GlancesStatsClient class."""
         # Init the plugin list dict
         self._plugins = collections.defaultdict(dict)
 
+        # Init the configuration
+        self.config = config
+
+        # Init the arguments
+        self.args = args
+
+        # Init the export modules list dict
+        self._exports = collections.defaultdict(dict)
+        # Load the plugins
+        self.load_exports(args=args)
+
     def set_plugins(self, input_plugins):
         """Set the plugin list according to the Glances server."""
         header = "glances_"
@@ -215,11 +291,20 @@ class GlancesStatsClient(GlancesStats):
             # The key is the plugin name
             # for example, the file glances_xxx.py
             # generate self._plugins_list["xxx"] = ...
-            logger.debug("Init {0} plugin".format(item))
+            logger.debug("Server uses {0} plugin".format(item))
             self._plugins[item] = plugin.Plugin()
         # Restoring system path
         sys.path = sys_path
 
+    def update(self, input_stats):
+        """Update all the stats."""
+        # For Glances client mode
+        for p in input_stats:
+            # Update plugin stats with items sent by the server
+            self._plugins[p].set_stats(input_stats[p])
+            # Update the views for the updated stats
+            self._plugins[p].update_views()
+
 
 class GlancesStatsClientSNMP(GlancesStats):
 
@@ -241,6 +326,11 @@ class GlancesStatsClientSNMP(GlancesStats):
         # Load plugins
         self.load_plugins(args=self.args)
 
+        # Init the export modules list dict
+        self._exports = collections.defaultdict(dict)
+        # Load the plugins
+        self.load_exports(args=args)
+
     def check_snmp(self):
         """Chek if SNMP is available on the server."""
         # Import the SNMP client class
