@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2014 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -23,7 +23,10 @@
 import sys
 
 # Import Glances lib
-from glances.core.glances_globals import glances_logs, glances_processes, is_mac, is_windows, logger
+from glances.core.glances_globals import is_mac, is_windows
+from glances.core.glances_logging import logger
+from glances.core.glances_logs import glances_logs
+from glances.core.glances_processes import glances_processes
 from glances.core.glances_timer import Timer
 
 # Import curses lib for "normal" operating system and consolelog for Windows
@@ -189,7 +192,7 @@ class _GlancesCurses(object):
         if args.enable_history:
             logger.info('Stats history enabled with output path %s' %
                         args.path_history)
-            from glances.outputs.glances_history import GlancesHistory
+            from glances.exports.glances_history import GlancesHistory
             self.glances_history = GlancesHistory(args.path_history)
             if not self.glances_history.graph_enabled():
                 args.enable_history = False
@@ -263,6 +266,9 @@ class _GlancesCurses(object):
         elif self.pressedkey == ord('d'):
             # 'd' > Show/hide disk I/O stats
             self.args.disable_diskio = not self.args.disable_diskio
+        elif self.pressedkey == ord('D'):
+            # 'D' > Show/hide Docker stats
+            self.args.disable_docker = not self.args.disable_docker
         elif self.pressedkey == ord('e'):
             # 'e' > Enable/Disable extended stats for top process
             self.args.enable_process_extended = not self.args.enable_process_extended
@@ -303,6 +309,9 @@ class _GlancesCurses(object):
         elif self.pressedkey == ord('r'):
             # 'r' > Reset history
             self.reset_history_tag = not self.reset_history_tag
+        elif self.pressedkey == ord('R'):
+            # 'R' > Hide RAID plugins
+            self.args.disable_raid = not self.args.disable_raid
         elif self.pressedkey == ord('s'):
             # 's' > Show/hide sensors stats (Linux-only)
             self.args.disable_sensors = not self.args.disable_sensors
@@ -421,9 +430,13 @@ class _GlancesCurses(object):
             'diskio').get_stats_display(args=self.args)
         stats_fs = stats.get_plugin('fs').get_stats_display(
             args=self.args, max_width=plugin_max_width)
+        stats_raid = stats.get_plugin('raid').get_stats_display(
+            args=self.args)
         stats_sensors = stats.get_plugin(
             'sensors').get_stats_display(args=self.args)
         stats_now = stats.get_plugin('now').get_stats_display()
+        stats_docker = stats.get_plugin('docker').get_stats_display(
+            args=self.args)
         stats_processcount = stats.get_plugin(
             'processcount').get_stats_display(args=self.args)
         stats_monitor = stats.get_plugin(
@@ -433,7 +446,8 @@ class _GlancesCurses(object):
 
         # Adapt number of processes to the available space
         max_processes_displayed = screen_y - 11 - \
-            self.get_stats_display_height(stats_alert)
+            self.get_stats_display_height(stats_alert) - \
+            self.get_stats_display_height(stats_docker)
         if self.args.enable_process_extended and not self.args.process_tree:
             max_processes_displayed -= 4
         if max_processes_displayed < 0:
@@ -504,7 +518,8 @@ class _GlancesCurses(object):
         # Display left sidebar (NETWORK+DISKIO+FS+SENSORS+Current time)
         self.init_column()
         if (not (self.args.disable_network and self.args.disable_diskio
-                 and self.args.disable_fs and self.args.disable_sensors)) \
+                 and self.args.disable_fs and self.args.disable_raid
+                 and self.args.disable_sensors)) \
                 and not self.args.disable_left_sidebar:
             self.new_line()
             self.display_plugin(stats_network)
@@ -513,6 +528,8 @@ class _GlancesCurses(object):
             self.new_line()
             self.display_plugin(stats_fs)
             self.new_line()
+            self.display_plugin(stats_raid)
+            self.new_line()
             self.display_plugin(stats_sensors)
             self.new_line()
             self.display_plugin(stats_now)
@@ -523,9 +540,11 @@ class _GlancesCurses(object):
             self.next_line = self.saved_line
 
             # Display right sidebar
-            # (PROCESS_COUNT+MONITORED+PROCESS_LIST+ALERT)
+            # ((DOCKER)+PROCESS_COUNT+(MONITORED)+PROCESS_LIST+ALERT)
             self.new_column()
             self.new_line()
+            self.display_plugin(stats_docker)
+            self.new_line()
             self.display_plugin(stats_processcount)
             if glances_processes.get_process_filter() is None and cs_status == 'None':
                 # Do not display stats monitor list if a filter exist
@@ -686,6 +705,7 @@ class _GlancesCurses(object):
 
         # Display
         x = display_x
+        x_max = x
         y = display_y
         for m in plugin_stats['msgdict']:
             # New line
@@ -729,9 +749,11 @@ class _GlancesCurses(object):
                     # good
                     offset = len(m['msg'])
                 x = x + offset
+                if x > x_max:
+                    x_max = x
 
         # Compute the next Glances column/line position
-        self.next_column = max(self.next_column, x + self.space_between_column)
+        self.next_column = max(self.next_column, x_max + self.space_between_column)
         self.next_line = max(self.next_line, y + self.space_between_line)
 
     def erase(self):
