@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2014 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -20,11 +20,10 @@
 """Alert plugin."""
 
 # Import system lib
-import types
 from datetime import datetime
 
 # Import Glances libs
-from glances.core.glances_globals import glances_logs
+from glances.core.glances_logs import glances_logs
 from glances.plugins.glances_plugin import GlancesPlugin
 
 
@@ -68,7 +67,7 @@ class Plugin(GlancesPlugin):
 
         # Build the string message
         # Header
-        if self.stats == []:
+        if not self.stats:
             msg = _("No warning or critical alert detected")
             ret.append(self.curse_add_line(msg, "TITLE"))
         else:
@@ -126,6 +125,6 @@ class Plugin(GlancesPlugin):
         Compare a with b using the tolerance (if numerical)
         """
         if str(int(a)).isdigit() and str(int(b)).isdigit():
-            return abs(a-b) <= max(abs(a), abs(b)) * tolerance
+            return abs(a - b) <= max(abs(a), abs(b)) * tolerance
         else:
             return a == b
